==> bbb-v0.9.4.zip: bbb/messages/de/base.php <==
<?php

return [
    'A live session' => 'Eine Videokonferenz',
    'Adds sessions to this container.' => 'Videokonferenz zu diesem Bereich hinzufügen.',
    'Adds sessions to this space.' => 'Videokonferenzen zu diesem Space hinzufügen.',
    'Adds sessions to your profile.' => 'Videokonferenzen zu deinem Profil hinzufügen.',
    'Administer conference sessions' => 'Videokonferenzen verwalten',
    'All users will be muted when entering the session.' => 'Alle Teilnehmer*innen werden stummgeschaltet, wenn sie der Sitzung beitreten.',
    'Allow everybody with access by humhub settings to join this session. Uncheck to select specific users below.' => 'Alle Benutzer*innen mit Humhub-Berechtigung dürfen dieser Sitzung beitreten. Deaktiviere diese Option, um unten bestimmte Benutzer*innen auszuwählen.',
    'Allow everybody with join permission to moderate this session.' => 'Alle Benutzer*innen mit Beitrittsberechtigung dürfen diese Sitzung moderieren.',
    'Allow everybody with join permission to start this session.' => 'Alle Benutzer*innen mit Beitrittsberechtigung dürfen diese Sitzung starten.',
    'Allow everybody with manage access by humhub settings to moderate this session. Uncheck to select specific users below.' => 'Alle Benutzer*innen mit Verwaltungszugriff gemäß den Humhub-Einstellungen dürfen diese Sitzung moderieren. Deaktiviere diese Option, um unten bestimmte Benutzer*innen auszuwählen.',
    'Allow public joining by a shareable link.' => 'Erlaube den öffentlichen Beitritt über einen teilbaren Link.',
    'Allow recording this session.' => 'Erlaube die Aufzeichnung dieser Sitzung.',
    'Allows the user to join a session.' => 'Erlaubt der/dem Benutzer*in, an einem Online-Meeting teilzunehmen.',
    'Allows the user to maintain all sessions.' => 'Erlaubt der/dem Benutzer*in, alle Videokonferenzen zu verwalten.',
    'Allows the user to start a session.' => 'Erlaubt der/dem Benutzer*in, eine Videokonferenz zu starten.',
    'Are you sure you want to delete this session?' => 'Bist du sicher, dass du diese Videokonferenz löschen möchtest?',
    'Cancel' => 'Abbrechen',
    'Change presentation file.' => 'Ändere die Präsentationsdatei.',
    'Change session image.' => 'Ändere das Sitzungsbild.',
    'Close now' => 'Jetzt schließen',
    'Conference sessions' => 'Videokonferenzen',
    'Copy public access URL to clipboard' => 'Öffentliche Zugangs-URL in die Zwischenablage kopieren',
    'Could not delete session.' => 'Konnte Videokonferenz nicht löschen.',
    'Could not save image reference to database.' => 'Konnte Bild nicht in die Datenbank speichern.',
    'Could not save presentation reference to database.' => 'Präsentationsreferenz konnte nicht in der Datenbank gespeichert werden.',
    'Could not start session "{title}".' => 'Konnte Videokonferenz "{title}" nicht starten.',
    'Create session' => 'Videokonferenz erstellen',
    'Creates a public join link which can be used by anybody to join this session (no login required).' => 'Erstellt einen öffentlichen Beitrittslink, der von jedem verwendet werden kann, um dieser Sitzung beizutreten (kein Login erforderlich).',
    'Current presentation' => 'Aktuelle Präsentation',
    'Delete session' => 'Videokonferenz löschen',
    'Depublish recording' => 'Aufnahme verstecken',
    'Duration' => 'Dauer',
    'Edit session' => 'Videokonferenz bearbeiten',
    'Error loading recordings' => 'Fehler beim Laden der Aufzeichnungen',
    'Here you can manage your conference sessions.' => 'Hier kannst du deine Videokonferenzen verwalten.',
    'Join' => 'Beitreten',
    'Join by humhub permissions.' => 'Beitreten gemäß Humhub-Berechtigungen.',
    'Join can moderate' => 'Beitreten kann moderieren',
    'Join can start' => 'Beitreten kann starten',
    'Join link' => 'Beitrittslink',
    'Join now' => 'Jetzt beitreten',
    'Join online conference session' => 'Videokonferenz beitreten',
    'Join session' => 'Videokonferenz beitreten',
    'Join users via a waiting room and let a moderator accept them.' => 'Benutzer*innen über einen Warteraum nach Freigabe beitreten lassen.',
    'Live session' => 'Live-Session',
    'Live video session with BigBlueButton' => 'Videokonferenz mit BigBlueButton',
    'Loading recordings...' => 'Lade Aufzeichnungen...',
    'Moderate by humhub permissions' => 'Moderieren gemäß Humhub-Berechtigungen',
    'Mute on entry' => 'Stummschalten beim Betreten',
    'No conference sessions found.' => 'Keine Videokonferenzen gefunden.',
    'No recordings available' => 'Keine Aufzeichnungen verfügbar',
    'No such session.' => 'Keine solche Sitzung.',
    'Only lowercase letters, numbers and hyphens are allowed.' => 'Es sind nur Kleinbuchstaben, Zahlen und Bindestriche erlaubt.',
    'Optional detailed description of the session and it\'s purpose.' => 'Optionale detaillierte Beschreibung der Sitzung und ihres Zwecks.',
    'Optional image for this session. Recommended size: 800x600px.' => 'Optionales Bild für diese Sitzung. Empfohlene Größe: 800x600px.',
    'Optional presentation for this session. Use pdf in landscape mode.' => 'Optionale Präsentation für diese Sitzung. Verwenden Sie PDF im Querformat.',
    'PDF preview' => 'PDF-Vorschau',
    'Play recording in new window' => 'Aufzeichnung in neuem Fenster abspielen',
    'Please describe...' => 'Bitte beschreibe...',
    'Please enter your name below:' => 'Bitte geben Sie Ihren Namen unten ein:',
    'Public join link for this session: <a href="{link}">{link}</a>' => 'Öffentlicher Beitrittslink für diese Sitzung: <a href="{link}">{link}</a>',
    'Publish recording' => 'Aufnahme veröffentlichen',
    'Recordings must be started manually.' => 'Aufzeichnungen müssen manuell gestartet werden.',
    'Running' => 'Online',
    'Save' => 'Speichern',
    'Select specific attendees for this session.' => 'Bestimmte Teilnehmer*innen für diese Sitzung auswählen.',
    'Select specific moderators for this session.' => 'Bestimmte Moderator*innen für diese Sitzung auswählen.',
    'Session created.' => 'Videokonferenz erstellt.',
    'Session deleted.' => 'Videokonferenz gelöscht.',
    'Session image' => 'Videokonferenz-Bild',
    'Session not found.' => 'Videokonferenz nicht gefunden.',
    'Session not public.' => 'Sitzung nicht öffentlich.',
    'Session not running.' => 'Sitzung nicht aktiv.',
    'Session saved.' => 'Videokonferenz gespeichert.',
    'Session with Id {id} not found.' => 'Videokonferenz mit Id {id} nicht gefunden.',
    'Speaking name for your audience, e.g. "Weekly Team Meeting"' => 'Sprechender Name für dein Publikum, z.B. "Wöchentliches Team-Meeting"',
    'Start' => 'Starten',
    'Start online conference session' => 'Starte Videokonferenz',
    'Start session' => 'Videokonferenz starten',
    'Stopped' => 'Pausiert',
    'The meeting has ended.' => 'Die Konferenz ist beendet.',
    'This name has already been taken.' => 'Dieser Name ist bereits vergeben.',
    'Upload presentation file.' => 'Präsentationsdatei hochladen.',
    'Upload session image.' => 'Sitzungsbild hochladen.',
    'Used as identifier and for the URL of the session, e.g. "weekly-team-meeting"' => 'Wird als Kennung und für die URL der Sitzung verwendet, z.B. "weekly-team-meeting"',
    'View' => 'Ansehen',
    'View session details' => 'Sitzungsdetails anzeigen',
    'Waiting room' => 'Warteraum',
    'You are moderator' => 'Du hast Moderationsrechte',
    'You are not allowed to start session "{title}".' => 'Du bist nicht berechtigt, die Videokonferenz "{title}" zu starten.',
    'You can create a new session by clicking the button above.' => 'Du kannst eine neue Videokonferenz erstellen, indem du auf die Schaltfläche oben klickst.',
    'You can now close this window.' => 'Du kannst dieses Fenster jetzt schließen.',
    'You will be redirected when the session starts.' => 'Sie werden umgeleitet, wenn die Sitzung beginnt.',
    'Your name' => 'Ihr Name',
    'Control who can see this session.' => 'Verwalten, wer diese Sitzung sehen kann.',
    'Could not read image file.' => 'Konnte Bilddatei nicht lesen.',
    'Could not read presentation file.' => 'Konnte Präsentationsdatei nicht lesen.',
];

==> bbb-v0.9.6.zip: bbb/messages/de/base.php <==
<?php

return [
    'A live session' => 'Eine Videokonferenz',
    'Adds sessions to this container.' => 'Videokonferenz zu diesem Bereich hinzufügen.',
    'Adds sessions to this space.' => 'Videokonferenzen zu diesem Space hinzufügen.',
    'Adds sessions to your profile.' => 'Videokonferenzen zu deinem Profil hinzufügen.',
    'Administer conference sessions' => 'Videokonferenzen verwalten',
    'All users will be muted when entering the session.' => 'Alle Teilnehmer*innen werden stummgeschaltet, wenn sie der Sitzung beitreten.',
    'Allow everybody with access by humhub settings to join this session. Uncheck to select specific users below.' => 'Alle Benutzer*innen mit Humhub-Berechtigung dürfen dieser Sitzung beitreten. Deaktiviere diese Option, um unten bestimmte Benutzer*innen auszuwählen.',
    'Allow everybody with join permission to moderate this session.' => 'Alle Benutzer*innen mit Beitrittsberechtigung dürfen diese Sitzung moderieren.',
    'Allow everybody with join permission to start this session.' => 'Alle Benutzer*innen mit Beitrittsberechtigung dürfen diese Sitzung starten.',
    'Allow everybody with manage access by humhub settings to moderate this session. Uncheck to select specific users below.' => 'Alle Benutzer*innen mit Verwaltungszugriff gemäß den Humhub-Einstellungen dürfen diese Sitzung moderieren. Deaktiviere diese Option, um unten bestimmte Benutzer*innen auszuwählen.',
    'Allow public joining by a shareable link.' => 'Erlaube den öffentlichen Beitritt über einen teilbaren Link.',
    'Allow recording this session.' => 'Erlaube die Aufzeichnung dieser Sitzung.',
    'Allows the user to join a session.' => 'Erlaubt der/dem Benutzer*in, an einem Online-Meeting teilzunehmen.',
    'Allows the user to maintain all sessions.' => 'Erlaubt der/dem Benutzer*in, alle Videokonferenzen zu verwalten.',
    'Allows the user to start a session.' => 'Erlaubt der/dem Benutzer*in, eine Videokonferenz zu starten.',
    'Are you sure you want to delete this session?' => 'Bist du sicher, dass du diese Videokonferenz löschen möchtest?',
    'Camera background image' => 'Videokonferenz-Hintergrundbild',
    'Cancel' => 'Abbrechen',
    'Change camera background image.' => 'Anpassen des Kamera-Hintergrundbildes.',
    'Change presentation file.' => 'Ändere die Präsentationsdatei.',
    'Change session image.' => 'Ändere das Sitzungsbild.',
    'Close now' => 'Jetzt schließen',
    'Conference sessions' => 'Videokonferenzen',
    'Control who can see this session.' => 'Verwalten, wer diese Sitzung sehen kann.',
    'Copy members access URL to clipboard' => 'Mitglieder-Zugangs-URL in die Zwischenablage kopieren',
    'Copy public access URL to clipboard' => 'Öffentliche Zugangs-URL in die Zwischenablage kopieren',
    'Could not delete session.' => 'Konnte Videokonferenz nicht löschen.',
    'Could not read camera background image file.' => 'Konnte die Bilddatei für den Kamera-Hintergrund nicht lesen.',
    'Could not read image file.' => 'Konnte Bilddatei nicht lesen.',
    'Could not read presentation file.' => 'Konnte Präsentationsdatei nicht lesen.',
    'Could not save camera background image reference to database.' => 'Konnte die Referenz des Kamera-Hintergrundbildes nicht in der Datenbank speichern.',
    'Could not save image reference to database.' => 'Konnte Bild nicht in die Datenbank speichern.',
    'Could not save presentation reference to database.' => 'Präsentationsreferenz konnte nicht in der Datenbank gespeichert werden.',
    'Could not start session "{title}".' => 'Konnte Videokonferenz "{title}" nicht starten.',
    'Create session' => 'Videokonferenz erstellen',
    'Creates a public join link which can be used by anybody to join this session (no login required).' => 'Erstellt einen öffentlichen Beitrittslink, der von jedem verwendet werden kann, um dieser Sitzung beizutreten (kein Login erforderlich).',
    'Current presentation' => 'Aktuelle Präsentation',
    'Delete session' => 'Videokonferenz löschen',
    'Depublish recording' => 'Aufnahme verstecken',
    'Duration' => 'Dauer',
    'Edit session' => 'Videokonferenz bearbeiten',
    'Error loading recordings' => 'Fehler beim Laden der Aufzeichnungen',
    'Here you can manage your conference sessions.' => 'Hier kannst du deine Videokonferenzen verwalten.',
    'Join' => 'Beitreten',
    'Join by humhub permissions.' => 'Beitreten gemäß Humhub-Berechtigungen.',
    'Join can moderate' => 'Beitreten kann moderieren',
    'Join can start' => 'Beitreten kann starten',
    'Join now' => 'Jetzt beitreten',
    'Join online conference session' => 'Videokonferenz beitreten',
    'Join session' => 'Videokonferenz beitreten',
    'Join users via a waiting room and let a moderator accept them.' => 'Benutzer*innen über einen Warteraum nach Freigabe beitreten lassen.',
    'Live session' => 'Live-Session',
    'Live video session with BigBlueButton' => 'Videokonferenz mit BigBlueButton',
    'Loading recordings...' => 'Lade Aufzeichnungen...',
    'Members join link' => 'Teilnahmelink für Mitglieder',
    'Moderate by humhub permissions' => 'Moderieren gemäß Humhub-Berechtigungen',
    'Mute on entry' => 'Stummschalten beim Betreten',
    'No conference sessions found.' => 'Keine Videokonferenzen gefunden.',
    'No recordings available' => 'Keine Aufzeichnungen verfügbar',
    'No such session.' => 'Keine solche Sitzung.',
    'Only lowercase letters, numbers and hyphens are allowed.' => 'Es sind nur Kleinbuchstaben, Zahlen und Bindestriche erlaubt.',
    'Optional background image for user cameras. Recommended size: at least 800x600px.' => 'Optionales Hintergrundbild für Benutzerkameras. Empfohlene Größe: mindestens 800x600px.',
    'Optional detailed description of the session and it\'s purpose.' => 'Optionale detaillierte Beschreibung der Sitzung und ihres Zwecks.',
    'Optional image for this session. Recommended size: 800x600px.' => 'Optionales Bild für diese Sitzung. Empfohlene Größe: 800x600px.',
    'Optional presentation for this session. Use pdf in landscape mode.' => 'Optionale Präsentation für diese Sitzung. Verwenden Sie PDF im Querformat.',
    'PDF preview' => 'PDF-Vorschau',
    'Play recording in new window' => 'Aufzeichnung in neuem Fenster abspielen',
    'Please describe...' => 'Bitte beschreibe...',
    'Please enter your name below:' => 'Bitte geben Sie Ihren Namen unten ein:',
    'Public Join link' => 'Teilnahmelink für Gäste',
    'Public join link for this session: <a href="{link}">{link}</a>' => 'Öffentlicher Beitrittslink für diese Sitzung: <a href="{link}">{link}</a>',
    'Publish recording' => 'Aufnahme veröffentlichen',
    'Recordings must be started manually.' => 'Aufzeichnungen müssen manuell gestartet werden.',
    'Running' => 'Online',
    'Save' => 'Speichern',
    'Select specific attendees for this session.' => 'Bestimmte Teilnehmer*innen für diese Sitzung auswählen.',
    'Select specific moderators for this session.' => 'Bestimmte Moderator*innen für diese Sitzung auswählen.',
    'Session created.' => 'Videokonferenz erstellt.',
    'Session deleted.' => 'Videokonferenz gelöscht.',
    'Session image' => 'Videokonferenz-Bild',
    'Session not found.' => 'Videokonferenz nicht gefunden.',
    'Session not public.' => 'Sitzung nicht öffentlich.',
    'Session not running.' => 'Sitzung nicht aktiv.',
    'Session saved.' => 'Videokonferenz gespeichert.',
    'Session with Id {id} not found.' => 'Videokonferenz mit Id {id} nicht gefunden.',
    'Speaking name for your audience, e.g. "Weekly Team Meeting"' => 'Sprechender Name für dein Publikum, z.B. "Wöchentliches Team-Meeting"',
    'Start' => 'Starten',
    'Start online conference session' => 'Starte Videokonferenz',
    'Start session' => 'Videokonferenz starten',
    'Stopped' => 'Pausiert',
    'The meeting has ended.' => 'Die Konferenz ist beendet.',
    'This name has already been taken.' => 'Dieser Name ist bereits vergeben.',
    'Upload camera background image.' => 'Kamera-Hintergrundbild hochladen.',
    'Upload presentation file.' => 'Präsentationsdatei hochladen.',
    'Upload session image.' => 'Sitzungsbild hochladen.',
    'Used as identifier and for the URL of the session, e.g. "weekly-team-meeting"' => 'Wird als Kennung und für die URL der Sitzung verwendet, z.B. "weekly-team-meeting"',
    'View' => 'Ansehen',
    'View session details' => 'Sitzungsdetails anzeigen',
    'Waiting room' => 'Warteraum',
    'You are moderator' => 'Du hast Moderationsrechte',
    'You are not allowed to start session "{title}".' => 'Du bist nicht berechtigt, die Videokonferenz "{title}" zu starten.',
    'You can create a new session by clicking the button above.' => 'Du kannst eine neue Videokonferenz erstellen, indem du auf die Schaltfläche oben klickst.',
    'You can now close this window.' => 'Du kannst dieses Fenster jetzt schließen.',
    'You will be redirected when the session starts.' => 'Du wirst umgeleitet, wenn die Sitzung beginnt.',
    'Your name' => 'Dein Name',
    ' Participants will be placed in the waiting room until a moderator accepts them.' => ' Teilnehmer*innen werden im Warteraum platziert, bis ein Moderator sie akzeptiert.',
    ' Participants will enter directly.' => ' Teilnehmer*innen treten direkt bei.',
    'You are the moderator of this session. As such, you have additional permissions and responsibilities compared to regular participants. Moderators can not be randomly assigned to breakout rooms!' => 'Du bist der Moderator dieser Sitzung. Daher hast du zusätzliche Berechtigungen und Verantwortlichkeiten im Vergleich zu regulären Teilnehmer*innen. Moderatoren können nicht zufällig auf Breakout-Räume verteilt werden!',
];
